==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ANullConstant.h <==
// public final class soot.jimple.parser.node.ANullConstant

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fc5435dd77c74b9e soot_jimple_parser_node_ANullConstant
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3f200529376bcdc9 soot_jimple_parser_node_PConstant

// header file dependencies
// @dep_header soot_jimple_parser_node_PConstant

#include "soot/jimple/parser/node/PConstant.h"

#ifndef _JC_soot_jimple_parser_node_ANullConstant_H_
#define _JC_soot_jimple_parser_node_ANullConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TNull$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ANullConstant$sub_refs	_jc_soot_jimple_parser_node_ANullConstant$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ANullConstant$sub_nonrefs	_jc_soot_jimple_parser_node_ANullConstant$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANullConstant$refs	_jc_soot_jimple_parser_node_ANullConstant$refs;
typedef struct _jc_soot_jimple_parser_node_ANullConstant$nonrefs	_jc_soot_jimple_parser_node_ANullConstant$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANullConstant$object	_jc_soot_jimple_parser_node_ANullConstant$object;

typedef const struct _jc_soot_jimple_parser_node_ANullConstant$vmethods	_jc_soot_jimple_parser_node_ANullConstant$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ANullConstant$vtable	_jc_soot_jimple_parser_node_ANullConstant$vtable;
typedef const struct _jc_soot_jimple_parser_node_ANullConstant$vtype	_jc_soot_jimple_parser_node_ANullConstant$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ANullConstant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *);
extern void _jc_soot_jimple_parser_node_ANullConstant$method$_init$15d2deba25cf6d34(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_soot_jimple_parser_node_TNull$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ANullConstant$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ANullConstant$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *);
extern struct _jc_soot_jimple_parser_node_TNull$object *_jc_soot_jimple_parser_node_ANullConstant$method$getNull$bdb72c13591edc06(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *);
extern void _jc_soot_jimple_parser_node_ANullConstant$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ANullConstant$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ANullConstant$method$setNull$1f379d6ee8dc7c87(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_soot_jimple_parser_node_TNull$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ANullConstant$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ANullConstant$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ANullConstant$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ANullConstant$method_info$getNull$bdb72c13591edc06;
extern _jc_method _jc_soot_jimple_parser_node_ANullConstant$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ANullConstant$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ANullConstant$method_info$setNull$1f379d6ee8dc7c87;
extern _jc_method _jc_soot_jimple_parser_node_ANullConstant$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ANullConstant$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *);
	struct _jc_soot_jimple_parser_node_TNull$object	*(*getNull$bdb72c13591edc06)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setNull$1f379d6ee8dc7c87)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_soot_jimple_parser_node_TNull$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ANullConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PConstant$vmethods	soot_jimple_parser_node_PConstant;
	_jc_soot_jimple_parser_node_ANullConstant$vmethods	soot_jimple_parser_node_ANullConstant;
};

// Vtype
struct _jc_soot_jimple_parser_node_ANullConstant$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ANullConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANullConstant$sub_refs {
	struct _jc_soot_jimple_parser_node_TNull$object	*__5fnull__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANullConstant$refs {
    _jc_soot_jimple_parser_node_ANullConstant$sub_refs	soot_jimple_parser_node_ANullConstant;
    _jc_soot_jimple_parser_node_PConstant$sub_refs	soot_jimple_parser_node_PConstant;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANullConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANullConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PConstant$sub_nonrefs	soot_jimple_parser_node_PConstant;
    _jc_soot_jimple_parser_node_ANullConstant$sub_nonrefs	soot_jimple_parser_node_ANullConstant;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ANullConstant$object {
	_jc_soot_jimple_parser_node_ANullConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ANullConstant$vtype	*vtype;
	_jc_soot_jimple_parser_node_ANullConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ANullConstant$vtype _jc_soot_jimple_parser_node_ANullConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ANullConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ANullConstant$class_object;

#endif	/* _JC_soot_jimple_parser_node_ANullConstant_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ANullConstant.h <==
// public final class soot.jimple.parser.node.ANullConstant

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fc5435dd77c74b9e soot_jimple_parser_node_ANullConstant
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3f200529376bcdc9 soot_jimple_parser_node_PConstant

// header file dependencies
// @dep_header soot_jimple_parser_node_PConstant

#include "soot/jimple/parser/node/PConstant.h"

#ifndef _JC_soot_jimple_parser_node_ANullConstant_H_
#define _JC_soot_jimple_parser_node_ANullConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TNull$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ANullConstant$sub_refs	_jc_soot_jimple_parser_node_ANullConstant$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ANullConstant$sub_nonrefs	_jc_soot_jimple_parser_node_ANullConstant$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANullConstant$refs	_jc_soot_jimple_parser_node_ANullConstant$refs;
typedef struct _jc_soot_jimple_parser_node_ANullConstant$nonrefs	_jc_soot_jimple_parser_node_ANullConstant$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANullConstant$object	_jc_soot_jimple_parser_node_ANullConstant$object;

typedef const struct _jc_soot_jimple_parser_node_ANullConstant$vmethods	_jc_soot_jimple_parser_node_ANullConstant$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ANullConstant$vtable	_jc_soot_jimple_parser_node_ANullConstant$vtable;
typedef const struct _jc_soot_jimple_parser_node_ANullConstant$vtype	_jc_soot_jimple_parser_node_ANullConstant$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ANullConstant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANullConstant$method$_init$15d2deba25cf6d34(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_soot_jimple_parser_node_TNull$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ANullConstant$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ANullConstant$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TNull$object *_jc_soot_jimple_parser_node_ANullConstant$method$getNull$bdb72c13591edc06(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANullConstant$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANullConstant$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANullConstant$method$setNull$1f379d6ee8dc7c87(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_soot_jimple_parser_node_TNull$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ANullConstant$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ANullConstant$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ANullConstant$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ANullConstant$method_info$getNull$bdb72c13591edc06;
extern _jc_method _jc_soot_jimple_parser_node_ANullConstant$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ANullConstant$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ANullConstant$method_info$setNull$1f379d6ee8dc7c87;
extern _jc_method _jc_soot_jimple_parser_node_ANullConstant$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ANullConstant$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TNull$object	*(*getNull$bdb72c13591edc06)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setNull$1f379d6ee8dc7c87)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *, struct _jc_soot_jimple_parser_node_TNull$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullConstant$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ANullConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PConstant$vmethods	soot_jimple_parser_node_PConstant;
	_jc_soot_jimple_parser_node_ANullConstant$vmethods	soot_jimple_parser_node_ANullConstant;
};

// Vtype
struct _jc_soot_jimple_parser_node_ANullConstant$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ANullConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANullConstant$sub_refs {
	struct _jc_soot_jimple_parser_node_TNull$object	*__5fnull__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANullConstant$refs {
    _jc_soot_jimple_parser_node_ANullConstant$sub_refs	soot_jimple_parser_node_ANullConstant;
    _jc_soot_jimple_parser_node_PConstant$sub_refs	soot_jimple_parser_node_PConstant;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANullConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANullConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PConstant$sub_nonrefs	soot_jimple_parser_node_PConstant;
    _jc_soot_jimple_parser_node_ANullConstant$sub_nonrefs	soot_jimple_parser_node_ANullConstant;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ANullConstant$object {
	_jc_soot_jimple_parser_node_ANullConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ANullConstant$vtype	*vtype;
	_jc_soot_jimple_parser_node_ANullConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ANullConstant$vtype _jc_soot_jimple_parser_node_ANullConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ANullConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ANullConstant$class_object;

#endif	/* _JC_soot_jimple_parser_node_ANullConstant_H_ */
